@@ -2,7 +2,7 @@ context("Testing group metadata retrieval and filtering")
 
 test_that("ki_group_list returns a tibble with three columns", {
   skip_if_net_down()
-  skip_if_exp_down()
+  skip_on_cran()
 
   group_test <- ki_group_list(hub = example_hub)
   static_names <- c("group_name", "group_id", "group_type")
